# arpes.plotting.stack\_plot module

**arpes.plotting.stack\_plot.stack\_dispersion\_plot(data:
Union\[xarray.core.dataarray.DataArray, xarray.core.dataset.Dataset\],
stack\_axis=None, ax=None, title=None, out=None, max\_stacks=100,
transpose=False, use\_constant\_correction=False, correction\_side=None,
color=None, c=None, label=None, shift=0, no\_scatter=False,
negate=False, s=1, scale\_factor=None, linewidth=1, palette=None,
zero\_offset=False, uniform=False,**kwargs)\*\*

**arpes.plotting.stack\_plot.flat\_stack\_plot(data:
Union\[xarray.core.dataarray.DataArray, xarray.core.dataset.Dataset\],
stack\_axis=None, fermi\_level=True, cbarmap=None, ax=None, mode='line',
title=None, out=None, transpose=False,**kwargs)\*\*
